type AccessibleDnaRegion implements GenomicEntity, ChemicalEntityOrGeneOrGeneProduct, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type Activity implements ActivityAndBehavior
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

interface ActivityAndBehavior
  {
  }

interface AdministrativeEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type Agent
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    affiliation: [Uriorcurie]
    address: String
    id: String!
    name: LabelType
  }

type AnatomicalEntity implements PhysicalEssence
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

interface AnatomicalEntityToAnatomicalEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: AnatomicalEntity!
    object: AnatomicalEntity!
  }

type AnatomicalEntityToAnatomicalEntityOntogenicAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: AnatomicalEntity!
    object: AnatomicalEntity!
    predicate: PredicateType!
  }

type AnatomicalEntityToAnatomicalEntityPartOfAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: AnatomicalEntity!
    object: AnatomicalEntity!
    predicate: PredicateType!
  }

interface Annotation
  {
  }

type Article
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
    publishedIn: Uriorcurie!
    isoAbbreviation: String
    volume: String
    issue: String
  }

type Association
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
  }

type Attribute implements OntologyClass
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type Bacterium
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type Behavior implements OntologyClass, ActivityAndBehavior
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type BehaviorToBehavioralFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: Behavior!
    object: BehavioralFeature!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type BehavioralExposure implements ExposureEvent
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
    timepoint: TimeType
  }

type BehavioralFeature
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type BehavioralOutcome implements Outcome
  {
  }

type BiologicalEntity implements ThingWithTaxon
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type BiologicalProcess implements Occurrent, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type BiologicalProcessOrActivity implements Occurrent, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type BiologicalSex
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type BioticExposure implements ExposureEvent
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
    timepoint: TimeType
  }

type Book
  {
    iri: IriType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    name: LabelType
    id: String!
    type: [String]
  }

type BookChapter
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
    publishedIn: Uriorcurie!
    volume: String
    chapter: String
  }

type Case implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

interface CaseToEntityAssociationMixin
  {
    subject: Case!
    predicate: PredicateType!
    object: NamedThing!
  }

type CaseToPhenotypicFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin, CaseToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type CausalGeneToDiseaseAssociation implements EntityToDiseaseAssociationMixin, GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    subject: GeneOrGeneProduct!
    object: Disease!
  }

type Cell
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type CellLine implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type CellLineAsAModelOfDiseaseAssociation implements ModelToDiseaseAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: CellLine!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
  }

type CellLineToDiseaseOrPhenotypicFeatureAssociation implements CellLineToEntityAssociationMixin, EntityToDiseaseOrPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: DiseaseOrPhenotypicFeature!
  }

interface CellLineToEntityAssociationMixin
  {
    subject: CellLine!
    predicate: PredicateType!
    object: NamedThing!
  }

type CellularComponent
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type CellularOrganism implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type ChemicalAffectsGeneAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    subjectDerivativeQualifier: ChemicalEntityDerivativeEnum
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    subjectContextQualifier: AnatomicalEntity
    subjectDirectionQualifier: DirectionQualifierEnum
    objectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    objectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    objectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectContextQualifier: AnatomicalEntity
    objectDirectionQualifier: DirectionQualifierEnum
    causalMechanismQualifier: CausalMechanismQualifierEnum
    anatomicalContextQualifier: AnatomicalEntity
    qualifiedPredicate: String
    speciesContextQualifier: OrganismTaxon
    subject: ChemicalEntity!
    predicate: PredicateType!
    object: GeneOrGeneProduct!
  }

type ChemicalEntity implements PhysicalEssence, ChemicalOrDrugOrTreatment, ChemicalEntityOrGeneOrGeneProduct, ChemicalEntityOrProteinOrPolypeptide
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
  }

type ChemicalEntityAssessesNamedThingAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: ChemicalEntity!
    object: NamedThing!
    predicate: PredicateType!
  }

interface ChemicalEntityOrGeneOrGeneProduct
  {
  }

type ChemicalEntityOrGeneOrGeneProductRegulatesGeneAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    objectDirectionQualifier: DirectionQualifierEnum
    predicate: PredicateType!
    subject: ChemicalEntityOrGeneOrGeneProduct!
    object: GeneOrGeneProduct!
  }

interface ChemicalEntityOrProteinOrPolypeptide
  {
  }

interface ChemicalEntityToEntityAssociationMixin
  {
    subject: ChemicalEntityOrGeneOrGeneProduct!
    predicate: PredicateType!
    object: NamedThing!
  }

type ChemicalExposure implements ExposureEvent
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQualitativeValue: NamedThing
    iri: IriType
    hasQuantitativeValue: [QuantityValue]
    timepoint: TimeType
  }

type ChemicalGeneInteractionAssociation implements ChemicalToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    subjectDerivativeQualifier: ChemicalEntityDerivativeEnum
    subjectContextQualifier: AnatomicalEntity
    objectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    objectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    objectContextQualifier: AnatomicalEntity
    anatomicalContextQualifier: AnatomicalEntity
    subject: ChemicalEntity!
    object: GeneOrGeneProduct!
    predicate: PredicateType!
  }

type ChemicalMixture
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: ChemicalMixture
    highestFDAApprovalStatus: String
    drugRegulatoryStatusWorldWide: String
    routesOfDelivery: [DrugDeliveryEnum]
  }

interface ChemicalOrDrugOrTreatment
  {
  }

type ChemicalOrDrugOrTreatmentSideEffectDiseaseOrPhenotypicFeatureAssociation implements ChemicalToEntityAssociationMixin, EntityToDiseaseOrPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    fDAAdverseEventLevel: FDAIDAAdverseEventEnum
    predicate: PredicateType!
  }

type ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation implements ChemicalToEntityAssociationMixin, EntityToDiseaseOrPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    fDAAdverseEventLevel: FDAIDAAdverseEventEnum
    predicate: PredicateType!
  }

type ChemicalRole
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type ChemicalToChemicalAssociation implements ChemicalToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: NamedThing!
    predicate: PredicateType!
    object: ChemicalEntity!
  }

type ChemicalToChemicalDerivationAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    catalystQualifier: [MacromolecularMachineMixin]
    subject: ChemicalEntity!
    object: ChemicalEntity!
    predicate: PredicateType!
  }

type ChemicalToDiseaseOrPhenotypicFeatureAssociation implements ChemicalToEntityAssociationMixin, EntityToDiseaseOrPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    object: DiseaseOrPhenotypicFeature!
  }

interface ChemicalToEntityAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
  }

type ChemicalToPathwayAssociation implements ChemicalToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: ChemicalEntity!
    object: Pathway!
  }

type ChiSquaredAnalysisResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type ClinicalAttribute
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type ClinicalCourse
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type ClinicalEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type ClinicalFinding
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [ClinicalAttribute]
  }

type ClinicalIntervention
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type ClinicalMeasurement
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
    hasAttributeType: OntologyClass!
  }

type ClinicalModifier
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type ClinicalTrial
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type CodingSequence implements GenomicEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type Cohort implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type CommonDataElement
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type ComplexChemicalExposure
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type ComplexMolecularMixture
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: ChemicalMixture
    highestFDAApprovalStatus: String
    drugRegulatoryStatusWorldWide: String
    routesOfDelivery: [DrugDeliveryEnum]
  }

type ConceptCountAnalysisResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type ConfidenceLevel
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type ContributorAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: InformationContentEntity!
    predicate: PredicateType!
    object: Agent!
    qualifiers: [OntologyClass]
  }

type CorrelatedGeneToDiseaseAssociation implements EntityToDiseaseAssociationMixin, GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    subject: GeneOrGeneProduct!
    object: Disease!
  }

type Dataset
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type DatasetDistribution
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    distributionDownloadUrl: String
  }

type DatasetSummary
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    sourceWebPage: String
    sourceLogo: String
  }

type DatasetVersion
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    hasDataset: Dataset
    ingestDate: String
    hasDistribution: DatasetDistribution
  }

type Device
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type DiagnosticAid
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type Disease
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type DiseaseOrPhenotypicFeature
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type DiseaseOrPhenotypicFeatureExposure implements ExposureEvent, PathologicalEntityMixin
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
    timepoint: TimeType
  }

type DiseaseOrPhenotypicFeatureOutcome implements Outcome
  {
  }

interface DiseaseOrPhenotypicFeatureToEntityAssociationMixin
  {
    subject: DiseaseOrPhenotypicFeature!
    predicate: PredicateType!
    object: NamedThing!
  }

type DiseaseOrPhenotypicFeatureToGeneticInheritanceAssociation implements DiseaseOrPhenotypicFeatureToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    predicate: PredicateType!
    object: GeneticInheritance!
  }

type DiseaseOrPhenotypicFeatureToLocationAssociation implements DiseaseOrPhenotypicFeatureToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    object: AnatomicalEntity!
  }

interface DiseaseToEntityAssociationMixin
  {
    subject: Disease!
    predicate: PredicateType!
    object: NamedThing!
  }

type DiseaseToExposureEventAssociation implements DiseaseToEntityAssociationMixin, EntityToExposureEventAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
  }

type DiseaseToPhenotypicFeatureAssociation implements FrequencyQuantifier, EntityToPhenotypicFeatureAssociationMixin, DiseaseToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: Disease!
    object: PhenotypicFeature!
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
  }

type Drug implements ChemicalOrDrugOrTreatment, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: ChemicalMixture
    highestFDAApprovalStatus: String
    drugRegulatoryStatusWorldWide: String
    routesOfDelivery: [DrugDeliveryEnum]
  }

type DrugExposure implements ExposureEvent
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQualitativeValue: NamedThing
    iri: IriType
    hasQuantitativeValue: [QuantityValue]
    timepoint: TimeType
  }

type DrugLabel
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
  }

interface DrugToEntityAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
  }

type DrugToGeneAssociation implements DrugToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    object: GeneOrGeneProduct!
  }

type DrugToGeneInteractionExposure implements GeneGroupingMixin
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQualitativeValue: NamedThing
    iri: IriType
    hasQuantitativeValue: [QuantityValue]
    timepoint: TimeType
    hasGeneOrGeneProduct: [Gene]
  }

type DruggableGeneToDiseaseAssociation implements EntityToDiseaseAssociationMixin, GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    object: Disease!
    subject: GeneOrGeneProduct!
    predicate: PredicateType!
    hasEvidence: [DruggableGeneCategoryEnum]
  }

interface Entity
  {
    id: String!
    iri: IriType
    category: [CategoryType]
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
  }

type EntityToDiseaseAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    clinicalApprovalStatus: ClinicalApprovalStatusEnum
    maxResearchPhase: MaxResearchPhaseEnum
  }

interface EntityToDiseaseAssociationMixin
  {
    frequencyQualifier: FrequencyValue
    subject: NamedThing!
    predicate: PredicateType!
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    object: Disease!
  }

interface EntityToDiseaseOrPhenotypicFeatureAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: DiseaseOrPhenotypicFeature!
  }

interface EntityToExposureEventAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: ExposureEvent!
  }

interface EntityToFeatureOrDiseaseQualifiersMixin
  {
    frequencyQualifier: FrequencyValue
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
  }

interface EntityToOutcomeAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: Outcome!
  }

type EntityToPhenotypicFeatureAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    clinicalApprovalStatus: ClinicalApprovalStatusEnum
    maxResearchPhase: MaxResearchPhaseEnum
  }

type EntityToPhenotypicFeatureAssociationMixin implements FrequencyQuantifier
  {
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    subject: NamedThing!
    predicate: PredicateType!
    object: PhenotypicFeature!
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type EnvironmentalExposure implements ExposureEvent
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
    timepoint: TimeType
  }

type EnvironmentalFeature
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type EnvironmentalFoodContaminant
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
  }

type EnvironmentalProcess implements Occurrent
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type EpidemiologicalOutcome implements Outcome
  {
  }

interface EpigenomicEntity
  {
    hasBiologicalSequence: BiologicalSequence
  }

type Event
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type EvidenceType
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type Exon
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type ExonToTranscriptRelationship
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: Exon!
    object: Transcript!
  }

interface ExposureEvent
  {
    id: String!
    timepoint: TimeType
  }

type ExposureEventToOutcomeAssociation implements EntityToOutcomeAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    populationContextQualifier: PopulationOfIndividualOrganisms
    temporalContextQualifier: TimeType
  }

type ExposureEventToPhenotypicFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: ExposureEvent!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

interface FeatureOrDiseaseQualifiersToEntityMixin
  {
    frequencyQualifier: FrequencyValue
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
  }

type Food
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: ChemicalMixture
    highestFDAApprovalStatus: String
    drugRegulatoryStatusWorldWide: String
    routesOfDelivery: [DrugDeliveryEnum]
  }

type FoodAdditive
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
  }

interface FrequencyQualifierMixin
  {
    frequencyQualifier: FrequencyValue
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
  }

interface FrequencyQuantifier
  {
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type FunctionalAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: MacromolecularMachineMixin!
    object: OntologyClass!
  }

type Fungus
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type Gene implements GeneOrGeneProduct, GenomicEntity, ChemicalEntityOrGeneOrGeneProduct, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    symbol: String
    xref: [Uriorcurie]
    hasBiologicalSequence: BiologicalSequence
  }

type GeneAffectsChemicalAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    subjectDerivativeQualifier: String
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    subjectContextQualifier: AnatomicalEntity
    subjectDirectionQualifier: DirectionQualifierEnum
    objectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    objectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    objectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectContextQualifier: AnatomicalEntity
    objectDirectionQualifier: DirectionQualifierEnum
    objectDerivativeQualifier: ChemicalEntityDerivativeEnum
    causalMechanismQualifier: CausalMechanismQualifierEnum
    anatomicalContextQualifier: AnatomicalEntity
    qualifiedPredicate: String
    speciesContextQualifier: OrganismTaxon
    subject: GeneOrGeneProduct!
    predicate: PredicateType!
    object: ChemicalEntity!
  }

type GeneAsAModelOfDiseaseAssociation implements ModelToDiseaseAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    object: Disease!
    subject: GeneOrGeneProduct!
  }

interface GeneExpressionMixin
  {
    quantifierQualifier: OntologyClass
    expressionSite: AnatomicalEntity
    stageQualifier: LifeStage
    phenotypicState: DiseaseOrPhenotypicFeature
  }

type GeneFamily implements GeneGroupingMixin, ChemicalEntityOrGeneOrGeneProduct
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasGeneOrGeneProduct: [Gene]
  }

interface GeneGroupingMixin
  {
    hasGeneOrGeneProduct: [Gene]
  }

type GeneHasVariantThatContributesToDiseaseAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    subjectFormOrVariantQualifier: String
    subject: GeneOrGeneProduct!
    object: Disease!
    predicate: PredicateType!
  }

interface GeneOrGeneProduct
  {
    name: SymbolType
  }

interface GeneProductIsoformMixin
  {
    name: SymbolType
    synonym: [LabelType]
    xref: [Uriorcurie]
  }

interface GeneProductMixin
  {
    name: SymbolType
    synonym: [LabelType]
    xref: [Uriorcurie]
  }

type GeneToDiseaseAssociation implements EntityToDiseaseAssociationMixin, GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    subject: GeneOrGeneProduct!
    object: Disease!
  }

type GeneToDiseaseOrPhenotypicFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin, GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    subject: GeneOrGeneProduct!
    object: DiseaseOrPhenotypicFeature!
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

interface GeneToEntityAssociationMixin
  {
    subject: GeneOrGeneProduct!
    predicate: PredicateType!
    object: NamedThing!
  }

type GeneToExpressionSiteAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    stageQualifier: LifeStage
    quantifierQualifier: OntologyClass
    subject: GeneOrGeneProduct!
    object: AnatomicalEntity!
    predicate: PredicateType!
  }

interface GeneToGeneAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: GeneOrGeneProduct!
    object: GeneOrGeneProduct!
  }

type GeneToGeneCoexpressionAssociation implements GeneExpressionMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: GeneOrGeneProduct!
    object: GeneOrGeneProduct!
    predicate: PredicateType!
    quantifierQualifier: OntologyClass
    expressionSite: AnatomicalEntity
    stageQualifier: LifeStage
    phenotypicState: DiseaseOrPhenotypicFeature
  }

type GeneToGeneFamilyAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: Gene!
    object: GeneFamily!
    predicate: PredicateType!
  }

type GeneToGeneHomologyAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: GeneOrGeneProduct!
    predicate: PredicateType!
    object: GeneOrGeneProduct!
  }

type GeneToGeneProductRelationship
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: Gene!
    object: GeneProductMixin!
    predicate: PredicateType!
  }

type GeneToGoTermAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: Gene!
    object: OntologyClass!
  }

type GeneToPathwayAssociation implements GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: GeneOrGeneProduct!
    object: Pathway!
  }

type GeneToPhenotypicFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin, GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    subject: GeneOrGeneProduct!
    object: PhenotypicFeature!
  }

type GeneticInheritance
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type Genome implements GenomicEntity, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type GenomicBackgroundExposure implements ExposureEvent, GeneGroupingMixin, PhysicalEssence, GenomicEntity, ThingWithTaxon, OntologyClass
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
    timepoint: TimeType
    hasGeneOrGeneProduct: [Gene]
    hasBiologicalSequence: BiologicalSequence
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

interface GenomicEntity
  {
    hasBiologicalSequence: BiologicalSequence
  }

type GenomicSequenceLocalization
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    startInterbaseCoordinate: Integer
    endInterbaseCoordinate: Integer
    genomeBuild: StrandEnum
    strand: StrandEnum
    phase: PhaseEnum
    subject: NucleicAcidEntity!
    object: NucleicAcidEntity!
    predicate: PredicateType!
  }

type Genotype implements PhysicalEssence, GenomicEntity, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasZygosity: Zygosity
    hasBiologicalSequence: BiologicalSequence
  }

type GenotypeAsAModelOfDiseaseAssociation implements ModelToDiseaseAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    predicate: PredicateType!
    object: NamedThing!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    subject: Genotype!
  }

type GenotypeToDiseaseAssociation implements GenotypeToEntityAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
  }

interface GenotypeToEntityAssociationMixin
  {
    subject: Genotype!
    predicate: PredicateType!
    object: NamedThing!
  }

type GenotypeToGeneAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    predicate: PredicateType!
    subject: Genotype!
    object: Gene!
  }

type GenotypeToGenotypePartAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    predicate: PredicateType!
    subject: Genotype!
    object: Genotype!
  }

type GenotypeToPhenotypicFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin, GenotypeToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    predicate: PredicateType!
    subject: Genotype!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type GenotypeToVariantAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    predicate: PredicateType!
    subject: Genotype!
    object: SequenceVariant!
  }

type GenotypicSex
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type GeographicExposure implements ExposureEvent
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
    timepoint: TimeType
  }

type GeographicLocation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    latitude: Float
    longitude: Float
  }

type GeographicLocationAtTime
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    latitude: Float
    longitude: Float
    timepoint: TimeType
  }

type GrossAnatomicalStructure
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type Haplotype implements GenomicEntity, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type Hospitalization
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type HospitalizationOutcome implements Outcome
  {
  }

type Human implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type IndividualOrganism implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

interface InformationContentEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type InformationContentEntityToNamedThingAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: NamedThing!
    object: NamedThing!
    predicate: PredicateType!
  }

type Invertebrate
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type JournalArticle
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
    publishedIn: Uriorcurie!
    isoAbbreviation: String
    volume: String
    issue: String
  }

type LifeStage
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type LogOddsAnalysisResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type MacromolecularComplex implements MacromolecularMachineMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

interface MacromolecularMachineMixin
  {
    name: SymbolType
  }

type MacromolecularMachineToBiologicalProcessAssociation implements MacromolecularMachineToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: MacromolecularMachineMixin!
    object: BiologicalProcess!
  }

type MacromolecularMachineToCellularComponentAssociation implements MacromolecularMachineToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: MacromolecularMachineMixin!
    object: CellularComponent!
  }

interface MacromolecularMachineToEntityAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
  }

type MacromolecularMachineToMolecularActivityAssociation implements MacromolecularMachineToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: MacromolecularMachineMixin!
    object: MolecularActivity!
  }

type Mammal implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

interface MappingCollection
  {
    predicateMappings: [PredicateMapping]
  }

type MaterialSample implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type MaterialSampleDerivationAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: MaterialSample!
    predicate: PredicateType!
    object: NamedThing!
  }

type MaterialSampleToDiseaseOrPhenotypicFeatureAssociation implements MaterialSampleToEntityAssociationMixin, EntityToDiseaseOrPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
  }

interface MaterialSampleToEntityAssociationMixin
  {
    subject: MaterialSample!
    predicate: PredicateType!
    object: NamedThing!
  }

type MicroRNA
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

interface ModelToDiseaseAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
  }

type MolecularActivity implements Occurrent, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [MolecularEntity]
    hasOutput: [MolecularEntity]
    enabledBy: [MacromolecularMachineMixin]
  }

type MolecularActivityToChemicalEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: MolecularActivity!
    object: ChemicalEntity!
  }

type MolecularActivityToMolecularActivityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: MolecularActivity!
    object: MolecularActivity!
  }

type MolecularActivityToPathwayAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: MolecularActivity!
    object: Pathway!
    predicate: PredicateType!
  }

type MolecularEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isMetabolite: Boolean
  }

type MolecularMixture
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: ChemicalMixture
    highestFDAApprovalStatus: String
    drugRegulatoryStatusWorldWide: String
    routesOfDelivery: [DrugDeliveryEnum]
  }

type MortalityOutcome implements Outcome
  {
  }

type NamedThing
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type NamedThingAssociatedWithLikelihoodOfNamedThingAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: NamedThing!
    subjectAspectQualifier: String
    subjectContextQualifier: OntologyClass
    predicate: PredicateType!
    object: NamedThing!
    objectAspectQualifier: String
    objectContextQualifier: OntologyClass
    populationContextQualifier: PopulationOfIndividualOrganisms
  }

type NoncodingRNAProduct
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type NucleicAcidEntity implements GenomicEntity, ThingWithTaxon, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isMetabolite: Boolean
    hasBiologicalSequence: BiologicalSequence
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type NucleicAcidSequenceMotif
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type NucleosomeModification implements GeneProductIsoformMixin, GenomicEntity, EpigenomicEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type ObservedExpectedFrequencyAnalysisResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

interface Occurrent
  {
  }

type Onset
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

interface OntologyClass
  {
    id: String!
  }

type OrganismAttribute
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type OrganismTaxon
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    hasTaxonomicRank: TaxonomicRank
  }

interface OrganismTaxonToEntityAssociation
  {
    subject: OrganismTaxon!
    predicate: PredicateType!
    object: NamedThing!
  }

type OrganismTaxonToEnvironmentAssociation implements OrganismTaxonToEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: OrganismTaxon!
    object: NamedThing!
    predicate: PredicateType!
  }

type OrganismTaxonToOrganismTaxonAssociation implements OrganismTaxonToEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: OrganismTaxon!
    object: OrganismTaxon!
  }

type OrganismTaxonToOrganismTaxonInteraction
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    associatedEnvironmentalContext: String
    subject: OrganismTaxon!
    object: OrganismTaxon!
    predicate: PredicateType!
  }

type OrganismTaxonToOrganismTaxonSpecialization
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: OrganismTaxon!
    object: OrganismTaxon!
    predicate: PredicateType!
  }

type OrganismToOrganismAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: IndividualOrganism!
    object: IndividualOrganism!
  }

type OrganismalEntity implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type OrganismalEntityAsAModelOfDiseaseAssociation implements ModelToDiseaseAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: OrganismalEntity!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
  }

interface Outcome
  {
  }

type PairwiseGeneToGeneInteraction
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: GeneOrGeneProduct!
    object: GeneOrGeneProduct!
    predicate: PredicateType!
  }

type PairwiseMolecularInteraction
  {
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    interactingMoleculesCategory: OntologyClass
    subject: MolecularEntity!
    id: String!
    predicate: PredicateType!
    object: MolecularEntity!
  }

type Patent
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
  }

interface PathognomonicityQuantifier
  {
  }

type PathologicalAnatomicalExposure implements ExposureEvent
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
    timepoint: TimeType
  }

type PathologicalAnatomicalOutcome implements Outcome
  {
  }

type PathologicalAnatomicalStructure implements PathologicalEntityMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

interface PathologicalEntityMixin
  {
  }

type PathologicalProcess implements PathologicalEntityMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type PathologicalProcessExposure implements ExposureEvent
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
    timepoint: TimeType
  }

type PathologicalProcessOutcome implements Outcome
  {
  }

type Pathway implements OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type Phenomenon implements Occurrent
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type PhenotypicFeature
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type PhenotypicFeatureToDiseaseAssociation implements EntityToDiseaseAssociationMixin, PhenotypicFeatureToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type PhenotypicFeatureToEntityAssociationMixin implements FrequencyQuantifier
  {
    frequencyQualifier: FrequencyValue
    predicate: PredicateType!
    object: NamedThing!
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    subject: PhenotypicFeature!
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type PhenotypicQuality
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type PhenotypicSex
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type PhysicalEntity implements PhysicalEssence
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

interface PhysicalEssence
  {
  }

interface PhysicalEssenceOrOccurrent
  {
  }

type PhysiologicalProcess implements OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type PlanetaryEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type Plant
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type Polypeptide implements ChemicalEntityOrGeneOrGeneProduct, ChemicalEntityOrProteinOrPolypeptide
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type PopulationOfIndividualOrganisms implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type PopulationToPopulationAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: PopulationOfIndividualOrganisms!
    object: PopulationOfIndividualOrganisms!
    predicate: PredicateType!
  }

type PosttranslationalModification implements GeneProductIsoformMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type PredicateMapping
  {
    mappedPredicate: String
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    subjectFormOrVariantQualifier: String
    subjectPartQualifier: String
    subjectDerivativeQualifier: String
    subjectContextQualifier: String
    predicate: PredicateType!
    qualifiedPredicate: String
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    objectFormOrVariantQualifier: String
    objectPartQualifier: String
    objectDerivativeQualifier: String
    objectContextQualifier: String
    causalMechanismQualifier: CausalMechanismQualifierEnum
    anatomicalContextQualifier: String
    speciesContextQualifier: OrganismTaxon
    exactMatch: [NamedThing]
    narrowMatch: [NamedThing]
    broadMatch: [NamedThing]
  }

type PreprintPublication
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
  }

type Procedure implements ActivityAndBehavior
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type ProcessedMaterial
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: ChemicalMixture
    highestFDAApprovalStatus: String
    drugRegulatoryStatusWorldWide: String
    routesOfDelivery: [DrugDeliveryEnum]
  }

type Protein implements GeneProductMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type ProteinDomain implements GeneGroupingMixin, ChemicalEntityOrGeneOrGeneProduct
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasGeneOrGeneProduct: [Gene]
  }

type ProteinFamily implements GeneGroupingMixin, ChemicalEntityOrGeneOrGeneProduct
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasGeneOrGeneProduct: [Gene]
  }

type ProteinIsoform implements GeneProductIsoformMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type Publication
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
  }

type QuantityValue
  {
    hasUnit: Unit
    hasNumericValue: Double
  }

type ReactionToCatalystAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    predicate: PredicateType!
    stoichiometry: Integer
    reactionDirection: ReactionDirectionEnum
    reactionSide: ReactionSideEnum
    subject: MolecularEntity!
    object: GeneOrGeneProduct!
  }

type ReactionToParticipantAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    predicate: PredicateType!
    object: ChemicalEntity!
    stoichiometry: Integer
    reactionDirection: ReactionDirectionEnum
    reactionSide: ReactionSideEnum
    subject: MolecularEntity!
  }

type ReagentTargetedGene implements GenomicEntity, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type RegulatoryRegion implements GenomicEntity, ChemicalEntityOrGeneOrGeneProduct, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

interface RelationshipQuantifier
  {
  }

type RelationshipType
  {
    id: String!
  }

type RelativeFrequencyAnalysisResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type RetrievalSource
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    resourceId: Uriorcurie!
    resourceRole: ResourceRoleEnum!
    upstreamResourceIds: Uriorcurie
    xref: [Uriorcurie]
  }

type RNAProduct implements GeneProductMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type RNAProductIsoform implements GeneProductIsoformMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

interface SensitivityQuantifier
  {
  }

type SequenceAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
  }

type SequenceFeatureRelationship
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: NucleicAcidEntity!
    object: NucleicAcidEntity!
  }

type SequenceVariant implements GenomicEntity, PhysicalEssence, OntologyClass
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasGene: [Gene]
    hasBiologicalSequence: BiologicalSequence
    id: String!
  }

interface SequenceVariantModulatesTreatmentAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: SequenceVariant!
    object: Treatment!
  }

type Serial
  {
    iri: IriType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    name: LabelType
    isoAbbreviation: String
    volume: String
    issue: String
    id: String!
    type: [String]
  }

type SeverityValue
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type SiRNA
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type SmallMolecule
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    tradeName: ChemicalEntity
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isMetabolite: Boolean
    id: String!
  }

type Snv
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasGene: [Gene]
    hasBiologicalSequence: BiologicalSequence
    id: String!
  }

type SocioeconomicAttribute
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type SocioeconomicExposure implements ExposureEvent
  {
    id: String!
    type: [String]
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
    hasAttribute: [SocioeconomicAttribute]!
    timepoint: TimeType
  }

type SocioeconomicOutcome implements Outcome
  {
  }

interface SpecificityQuantifier
  {
  }

type Study
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
  }

type StudyPopulation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

interface StudyResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type StudyVariable
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

interface SubjectOfInvestigation
  {
  }

type TaxonToTaxonAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: OrganismTaxon!
    object: OrganismTaxon!
  }

type TaxonomicRank
  {
    id: String!
  }

type TextMiningResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

interface ThingWithTaxon
  {
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type Transcript
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type TranscriptToGeneRelationship
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: Transcript!
    object: Gene!
  }

type TranscriptionFactorBindingSite implements GenomicEntity, ChemicalEntityOrGeneOrGeneProduct, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type Treatment implements ExposureEvent, ChemicalOrDrugOrTreatment
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    hasDrug: [Drug]
    hasDevice: [Device]
    hasProcedure: [Procedure]
    timepoint: TimeType
  }

type VariantAsAModelOfDiseaseAssociation implements ModelToDiseaseAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    predicate: PredicateType!
    object: NamedThing!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    subject: SequenceVariant!
  }

type VariantToDiseaseAssociation implements VariantToEntityAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
  }

interface VariantToEntityAssociationMixin
  {
    subject: SequenceVariant!
    predicate: PredicateType!
    object: NamedThing!
  }

type VariantToGeneAssociation implements VariantToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    object: Gene!
    predicate: PredicateType!
  }

type VariantToGeneExpressionAssociation implements GeneExpressionMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    object: Gene!
    predicate: PredicateType!
    quantifierQualifier: OntologyClass
    expressionSite: AnatomicalEntity
    stageQualifier: LifeStage
    phenotypicState: DiseaseOrPhenotypicFeature
  }

type VariantToPhenotypicFeatureAssociation implements VariantToEntityAssociationMixin, EntityToPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: SequenceVariant!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type VariantToPopulationAssociation implements VariantToEntityAssociationMixin, FrequencyQuantifier, FrequencyQualifierMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    type: [String]
    category: [CategoryType]
    subject: SequenceVariant!
    object: PopulationOfIndividualOrganisms!
    hasQuotient: Double
    hasCount: Integer
    hasTotal: Integer
    hasPercentage: Double
    frequencyQualifier: FrequencyValue
  }

type Vertebrate
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type Virus implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type WebPage
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
  }

type Zygosity
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    category: [CategoryType]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

